@@ -1,21 +1,16 @@
-# $Revision: #17 $$Date: 2003/09/04 $$Author: wsnyder $
+# $Revision: #20 $$Date: 2003/10/30 $$Author: wsnyder $
 # Author: Wilson Snyder <wsnyder@wsnyder.org>
 ######################################################################
 #
-# This program is Copyright 2001 by Wilson Snyder.
-#
-# This program is free software; you can redistribute it and/or modify
-# it under the terms of either the GNU General Public License or the
-# Perl Artistic License.
+# Copyright 2001-2003 by Wilson Snyder.  This program is free software;
+# you can redistribute it and/or modify it under the terms of either the GNU
+# General Public License or the Perl Artistic License.
 #
 # This program is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 # GNU General Public License for more details.
 #
-# If you do not have a copy of the GNU General Public License write to
-# the Free Software Foundation, Inc., 675 Mass Ave, Cambridge,
-# MA 02139, USA.
 ######################################################################
 
 package SystemC::Vregs::Subclass;
@@ -23,7 +18,7 @@ package SystemC::Vregs::Subclass;
 use strict;
 use vars qw($Errors $VERSION);
 use Carp;
-$VERSION = '1.242';
+$VERSION = '1.243';
 
 $Errors = 0;
 
@@ -90,7 +85,7 @@ sub clean_sentence {
     # Make it reasonably small, or the first sentence
     $field =~ s/^\s+//g;
     $field =~ s/\s*\bthis bit\b//g;
-    $field =~ s/\"/ /g;
+    $field =~ s/[\"\'\`]+/ /g;
     $field =~ s/\s+/ /g;
     $field = substr $field,0,80;
     if ($field =~ /[.,;]/) {
